# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities
from ._inputs import *

__all__ = ['ProviderArgs', 'Provider']

@pulumi.input_type
class ProviderArgs:
    def __init__(__self__, *,
                 app_auth: Optional[pulumi.Input['ProviderAppAuthArgs']] = None,
                 base_url: Optional[pulumi.Input[str]] = None,
                 insecure: Optional[pulumi.Input[bool]] = None,
                 organization: Optional[pulumi.Input[str]] = None,
                 owner: Optional[pulumi.Input[str]] = None,
                 token: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a Provider resource.
        :param pulumi.Input['ProviderAppAuthArgs'] app_auth: The GitHub App credentials used to connect to GitHub. Conflicts with `token`. Anonymous mode is enabled if both `token`
               and `app_auth` are not set.
        :param pulumi.Input[str] base_url: The GitHub Base API URL
        :param pulumi.Input[bool] insecure: Enable `insecure` mode for testing purposes
        :param pulumi.Input[str] organization: The GitHub organization name to manage. Use this field instead of `owner` when managing organization accounts.
        :param pulumi.Input[str] owner: The GitHub owner name to manage. Use this field instead of `organization` when managing individual accounts.
        :param pulumi.Input[str] token: The OAuth token used to connect to GitHub. Anonymous mode is enabled if both `token` and `app_auth` are not set.
        """
        if app_auth is not None:
            pulumi.set(__self__, "app_auth", app_auth)
        if base_url is None:
            base_url = (_utilities.get_env('GITHUB_BASE_URL') or 'https://api.github.com/')
        if base_url is not None:
            pulumi.set(__self__, "base_url", base_url)
        if insecure is not None:
            pulumi.set(__self__, "insecure", insecure)
        if organization is not None:
            warnings.warn("""Use owner (or GITHUB_OWNER) instead of organization (or GITHUB_ORGANIZATION)""", DeprecationWarning)
            pulumi.log.warn("""organization is deprecated: Use owner (or GITHUB_OWNER) instead of organization (or GITHUB_ORGANIZATION)""")
        if organization is not None:
            pulumi.set(__self__, "organization", organization)
        if owner is not None:
            pulumi.set(__self__, "owner", owner)
        if token is not None:
            pulumi.set(__self__, "token", token)

    @property
    @pulumi.getter(name="appAuth")
    def app_auth(self) -> Optional[pulumi.Input['ProviderAppAuthArgs']]:
        """
        The GitHub App credentials used to connect to GitHub. Conflicts with `token`. Anonymous mode is enabled if both `token`
        and `app_auth` are not set.
        """
        return pulumi.get(self, "app_auth")

    @app_auth.setter
    def app_auth(self, value: Optional[pulumi.Input['ProviderAppAuthArgs']]):
        pulumi.set(self, "app_auth", value)

    @property
    @pulumi.getter(name="baseUrl")
    def base_url(self) -> Optional[pulumi.Input[str]]:
        """
        The GitHub Base API URL
        """
        return pulumi.get(self, "base_url")

    @base_url.setter
    def base_url(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "base_url", value)

    @property
    @pulumi.getter
    def insecure(self) -> Optional[pulumi.Input[bool]]:
        """
        Enable `insecure` mode for testing purposes
        """
        return pulumi.get(self, "insecure")

    @insecure.setter
    def insecure(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "insecure", value)

    @property
    @pulumi.getter
    def organization(self) -> Optional[pulumi.Input[str]]:
        """
        The GitHub organization name to manage. Use this field instead of `owner` when managing organization accounts.
        """
        return pulumi.get(self, "organization")

    @organization.setter
    def organization(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "organization", value)

    @property
    @pulumi.getter
    def owner(self) -> Optional[pulumi.Input[str]]:
        """
        The GitHub owner name to manage. Use this field instead of `organization` when managing individual accounts.
        """
        return pulumi.get(self, "owner")

    @owner.setter
    def owner(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "owner", value)

    @property
    @pulumi.getter
    def token(self) -> Optional[pulumi.Input[str]]:
        """
        The OAuth token used to connect to GitHub. Anonymous mode is enabled if both `token` and `app_auth` are not set.
        """
        return pulumi.get(self, "token")

    @token.setter
    def token(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "token", value)


class Provider(pulumi.ProviderResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 app_auth: Optional[pulumi.Input[pulumi.InputType['ProviderAppAuthArgs']]] = None,
                 base_url: Optional[pulumi.Input[str]] = None,
                 insecure: Optional[pulumi.Input[bool]] = None,
                 organization: Optional[pulumi.Input[str]] = None,
                 owner: Optional[pulumi.Input[str]] = None,
                 token: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        The provider type for the github package. By default, resources use package-wide configuration
        settings, however an explicit `Provider` instance may be created and passed during resource
        construction to achieve fine-grained programmatic control over provider settings. See the
        [documentation](https://www.pulumi.com/docs/reference/programming-model/#providers) for more information.

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[pulumi.InputType['ProviderAppAuthArgs']] app_auth: The GitHub App credentials used to connect to GitHub. Conflicts with `token`. Anonymous mode is enabled if both `token`
               and `app_auth` are not set.
        :param pulumi.Input[str] base_url: The GitHub Base API URL
        :param pulumi.Input[bool] insecure: Enable `insecure` mode for testing purposes
        :param pulumi.Input[str] organization: The GitHub organization name to manage. Use this field instead of `owner` when managing organization accounts.
        :param pulumi.Input[str] owner: The GitHub owner name to manage. Use this field instead of `organization` when managing individual accounts.
        :param pulumi.Input[str] token: The OAuth token used to connect to GitHub. Anonymous mode is enabled if both `token` and `app_auth` are not set.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: Optional[ProviderArgs] = None,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        The provider type for the github package. By default, resources use package-wide configuration
        settings, however an explicit `Provider` instance may be created and passed during resource
        construction to achieve fine-grained programmatic control over provider settings. See the
        [documentation](https://www.pulumi.com/docs/reference/programming-model/#providers) for more information.

        :param str resource_name: The name of the resource.
        :param ProviderArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ProviderArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 app_auth: Optional[pulumi.Input[pulumi.InputType['ProviderAppAuthArgs']]] = None,
                 base_url: Optional[pulumi.Input[str]] = None,
                 insecure: Optional[pulumi.Input[bool]] = None,
                 organization: Optional[pulumi.Input[str]] = None,
                 owner: Optional[pulumi.Input[str]] = None,
                 token: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = _utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ProviderArgs.__new__(ProviderArgs)

            __props__.__dict__["app_auth"] = pulumi.Output.from_input(app_auth).apply(pulumi.runtime.to_json) if app_auth is not None else None
            if base_url is None:
                base_url = (_utilities.get_env('GITHUB_BASE_URL') or 'https://api.github.com/')
            __props__.__dict__["base_url"] = base_url
            __props__.__dict__["insecure"] = pulumi.Output.from_input(insecure).apply(pulumi.runtime.to_json) if insecure is not None else None
            if organization is not None and not opts.urn:
                warnings.warn("""Use owner (or GITHUB_OWNER) instead of organization (or GITHUB_ORGANIZATION)""", DeprecationWarning)
                pulumi.log.warn("""organization is deprecated: Use owner (or GITHUB_OWNER) instead of organization (or GITHUB_ORGANIZATION)""")
            __props__.__dict__["organization"] = organization
            __props__.__dict__["owner"] = owner
            __props__.__dict__["token"] = token
        super(Provider, __self__).__init__(
            'github',
            resource_name,
            __props__,
            opts)

    @property
    @pulumi.getter(name="baseUrl")
    def base_url(self) -> pulumi.Output[Optional[str]]:
        """
        The GitHub Base API URL
        """
        return pulumi.get(self, "base_url")

    @property
    @pulumi.getter
    def organization(self) -> pulumi.Output[Optional[str]]:
        """
        The GitHub organization name to manage. Use this field instead of `owner` when managing organization accounts.
        """
        return pulumi.get(self, "organization")

    @property
    @pulumi.getter
    def owner(self) -> pulumi.Output[Optional[str]]:
        """
        The GitHub owner name to manage. Use this field instead of `organization` when managing individual accounts.
        """
        return pulumi.get(self, "owner")

    @property
    @pulumi.getter
    def token(self) -> pulumi.Output[Optional[str]]:
        """
        The OAuth token used to connect to GitHub. Anonymous mode is enabled if both `token` and `app_auth` are not set.
        """
        return pulumi.get(self, "token")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities
from . import outputs

__all__ = [
    'GetOrganizationTeamsResult',
    'AwaitableGetOrganizationTeamsResult',
    'get_organization_teams',
]

@pulumi.output_type
class GetOrganizationTeamsResult:
    """
    A collection of values returned by getOrganizationTeams.
    """
    def __init__(__self__, id=None, root_teams_only=None, teams=None):
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if root_teams_only and not isinstance(root_teams_only, bool):
            raise TypeError("Expected argument 'root_teams_only' to be a bool")
        pulumi.set(__self__, "root_teams_only", root_teams_only)
        if teams and not isinstance(teams, list):
            raise TypeError("Expected argument 'teams' to be a list")
        pulumi.set(__self__, "teams", teams)

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="rootTeamsOnly")
    def root_teams_only(self) -> Optional[bool]:
        """
        Only return teams that are at the organization's root, i.e. no nested teams. Defaults to `false`.
        """
        return pulumi.get(self, "root_teams_only")

    @property
    @pulumi.getter
    def teams(self) -> Sequence['outputs.GetOrganizationTeamsTeamResult']:
        """
        An Array of GitHub Teams.  Each `team` block consists of the fields documented below.
        ___
        """
        return pulumi.get(self, "teams")


class AwaitableGetOrganizationTeamsResult(GetOrganizationTeamsResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetOrganizationTeamsResult(
            id=self.id,
            root_teams_only=self.root_teams_only,
            teams=self.teams)


def get_organization_teams(root_teams_only: Optional[bool] = None,
                           opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetOrganizationTeamsResult:
    """
    Use this data source to retrieve information about all GitHub teams in an organization.

    ## Example Usage

    To retrieve *all* teams of the organization:

    ```python
    import pulumi
    import pulumi_github as github

    all = github.get_organization_teams()
    ```

    To retrieve only the team's at the root of the organization:

    ```python
    import pulumi
    import pulumi_github as github

    root_teams = github.get_organization_teams(root_teams_only=True)
    ```


    :param bool root_teams_only: Only return teams that are at the organization's root, i.e. no nested teams. Defaults to `false`.
    """
    __args__ = dict()
    __args__['rootTeamsOnly'] = root_teams_only
    if opts is None:
        opts = pulumi.InvokeOptions()
    if opts.version is None:
        opts.version = _utilities.get_version()
    __ret__ = pulumi.runtime.invoke('github:index/getOrganizationTeams:getOrganizationTeams', __args__, opts=opts, typ=GetOrganizationTeamsResult).value

    return AwaitableGetOrganizationTeamsResult(
        id=__ret__.id,
        root_teams_only=__ret__.root_teams_only,
        teams=__ret__.teams)



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities

__all__ = [
    'GetTeamResult',
    'AwaitableGetTeamResult',
    'get_team',
]

@pulumi.output_type
class GetTeamResult:
    """
    A collection of values returned by getTeam.
    """
    def __init__(__self__, description=None, id=None, members=None, name=None, node_id=None, permission=None, privacy=None, repositories=None, slug=None):
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if members and not isinstance(members, list):
            raise TypeError("Expected argument 'members' to be a list")
        pulumi.set(__self__, "members", members)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if node_id and not isinstance(node_id, str):
            raise TypeError("Expected argument 'node_id' to be a str")
        pulumi.set(__self__, "node_id", node_id)
        if permission and not isinstance(permission, str):
            raise TypeError("Expected argument 'permission' to be a str")
        pulumi.set(__self__, "permission", permission)
        if privacy and not isinstance(privacy, str):
            raise TypeError("Expected argument 'privacy' to be a str")
        pulumi.set(__self__, "privacy", privacy)
        if repositories and not isinstance(repositories, list):
            raise TypeError("Expected argument 'repositories' to be a list")
        pulumi.set(__self__, "repositories", repositories)
        if slug and not isinstance(slug, str):
            raise TypeError("Expected argument 'slug' to be a str")
        pulumi.set(__self__, "slug", slug)

    @property
    @pulumi.getter
    def description(self) -> str:
        """
        the team's description.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def members(self) -> Sequence[str]:
        """
        List of team members
        """
        return pulumi.get(self, "members")

    @property
    @pulumi.getter
    def name(self) -> str:
        """
        the team's full name.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="nodeId")
    def node_id(self) -> str:
        """
        the Node ID of the team.
        """
        return pulumi.get(self, "node_id")

    @property
    @pulumi.getter
    def permission(self) -> str:
        """
        the team's permission level.
        """
        return pulumi.get(self, "permission")

    @property
    @pulumi.getter
    def privacy(self) -> str:
        """
        the team's privacy type.
        """
        return pulumi.get(self, "privacy")

    @property
    @pulumi.getter
    def repositories(self) -> Sequence[str]:
        """
        List of team repositories
        """
        return pulumi.get(self, "repositories")

    @property
    @pulumi.getter
    def slug(self) -> str:
        return pulumi.get(self, "slug")


class AwaitableGetTeamResult(GetTeamResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetTeamResult(
            description=self.description,
            id=self.id,
            members=self.members,
            name=self.name,
            node_id=self.node_id,
            permission=self.permission,
            privacy=self.privacy,
            repositories=self.repositories,
            slug=self.slug)


def get_team(slug: Optional[str] = None,
             opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetTeamResult:
    """
    Use this data source to retrieve information about a GitHub team.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_github as github

    example = github.get_team(slug="example")
    ```


    :param str slug: The team slug.
    """
    __args__ = dict()
    __args__['slug'] = slug
    if opts is None:
        opts = pulumi.InvokeOptions()
    if opts.version is None:
        opts.version = _utilities.get_version()
    __ret__ = pulumi.runtime.invoke('github:index/getTeam:getTeam', __args__, opts=opts, typ=GetTeamResult).value

    return AwaitableGetTeamResult(
        description=__ret__.description,
        id=__ret__.id,
        members=__ret__.members,
        name=__ret__.name,
        node_id=__ret__.node_id,
        permission=__ret__.permission,
        privacy=__ret__.privacy,
        repositories=__ret__.repositories,
        slug=__ret__.slug)



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs

__all__ = [
    'app_auth',
    'base_url',
    'insecure',
    'organization',
    'owner',
    'token',
]

__config__ = pulumi.Config('github')

app_auth = __config__.get('appAuth')
"""
The GitHub App credentials used to connect to GitHub. Conflicts with `token`. Anonymous mode is enabled if both `token`
and `app_auth` are not set.
"""

base_url = __config__.get('baseUrl') or (_utilities.get_env('GITHUB_BASE_URL') or 'https://api.github.com/')
"""
The GitHub Base API URL
"""

insecure = __config__.get('insecure')
"""
Enable `insecure` mode for testing purposes
"""

organization = __config__.get('organization')
"""
The GitHub organization name to manage. Use this field instead of `owner` when managing organization accounts.
"""

owner = __config__.get('owner')
"""
The GitHub owner name to manage. Use this field instead of `organization` when managing individual accounts.
"""

token = __config__.get('token')
"""
The OAuth token used to connect to GitHub. Anonymous mode is enabled if both `token` and `app_auth` are not set.
"""




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

from . import _utilities
import typing
# Export this package's modules as members:
from .actions_environment_secret import *
from .actions_organization_secret import *
from .actions_organization_secret_repositories import *
from .actions_runner_group import *
from .actions_secret import *
from .app_installation_repository import *
from .branch import *
from .branch_default import *
from .branch_protection import *
from .branch_protection_v3 import *
from .get_actions_public_key import *
from .get_branch import *
from .get_collaborators import *
from .get_ip_ranges import *
from .get_membership import *
from .get_organization import *
from .get_organization_team_sync_groups import *
from .get_organization_teams import *
from .get_release import *
from .get_repositories import *
from .get_repository import *
from .get_repository_milestone import *
from .get_repository_pull_request import *
from .get_repository_pull_requests import *
from .get_team import *
from .get_user import *
from .issue_label import *
from .membership import *
from .organization_block import *
from .organization_project import *
from .organization_webhook import *
from .project_card import *
from .project_column import *
from .provider import *
from .repository import *
from .repository_collaborator import *
from .repository_deploy_key import *
from .repository_environment import *
from .repository_file import *
from .repository_milestone import *
from .repository_project import *
from .repository_pull_request import *
from .repository_webhook import *
from .team import *
from .team_membership import *
from .team_repository import *
from .team_sync_group_mapping import *
from .user_gpg_key import *
from .user_invitation_accepter import *
from .user_ssh_key import *
from ._inputs import *
from . import outputs

# Make subpackages available:
if typing.TYPE_CHECKING:
    import pulumi_github.config as config
else:
    config = _utilities.lazy_import('pulumi_github.config')

_utilities.register(
    resource_modules="""
[
 {
  "pkg": "github",
  "mod": "index/actionsEnvironmentSecret",
  "fqn": "pulumi_github",
  "classes": {
   "github:index/actionsEnvironmentSecret:ActionsEnvironmentSecret": "ActionsEnvironmentSecret"
  }
 },
 {
  "pkg": "github",
  "mod": "index/actionsOrganizationSecret",
  "fqn": "pulumi_github",
  "classes": {
   "github:index/actionsOrganizationSecret:ActionsOrganizationSecret": "ActionsOrganizationSecret"
  }
 },
 {
  "pkg": "github",
  "mod": "index/actionsOrganizationSecretRepositories",
  "fqn": "pulumi_github",
  "classes": {
   "github:index/actionsOrganizationSecretRepositories:ActionsOrganizationSecretRepositories": "ActionsOrganizationSecretRepositories"
  }
 },
 {
  "pkg": "github",
  "mod": "index/actionsRunnerGroup",
  "fqn": "pulumi_github",
  "classes": {
   "github:index/actionsRunnerGroup:ActionsRunnerGroup": "ActionsRunnerGroup"
  }
 },
 {
  "pkg": "github",
  "mod": "index/actionsSecret",
  "fqn": "pulumi_github",
  "classes": {
   "github:index/actionsSecret:ActionsSecret": "ActionsSecret"
  }
 },
 {
  "pkg": "github",
  "mod": "index/appInstallationRepository",
  "fqn": "pulumi_github",
  "classes": {
   "github:index/appInstallationRepository:AppInstallationRepository": "AppInstallationRepository"
  }
 },
 {
  "pkg": "github",
  "mod": "index/branch",
  "fqn": "pulumi_github",
  "classes": {
   "github:index/branch:Branch": "Branch"
  }
 },
 {
  "pkg": "github",
  "mod": "index/branchDefault",
  "fqn": "pulumi_github",
  "classes": {
   "github:index/branchDefault:BranchDefault": "BranchDefault"
  }
 },
 {
  "pkg": "github",
  "mod": "index/branchProtection",
  "fqn": "pulumi_github",
  "classes": {
   "github:index/branchProtection:BranchProtection": "BranchProtection"
  }
 },
 {
  "pkg": "github",
  "mod": "index/branchProtectionV3",
  "fqn": "pulumi_github",
  "classes": {
   "github:index/branchProtectionV3:BranchProtectionV3": "BranchProtectionV3"
  }
 },
 {
  "pkg": "github",
  "mod": "index/issueLabel",
  "fqn": "pulumi_github",
  "classes": {
   "github:index/issueLabel:IssueLabel": "IssueLabel"
  }
 },
 {
  "pkg": "github",
  "mod": "index/membership",
  "fqn": "pulumi_github",
  "classes": {
   "github:index/membership:Membership": "Membership"
  }
 },
 {
  "pkg": "github",
  "mod": "index/organizationBlock",
  "fqn": "pulumi_github",
  "classes": {
   "github:index/organizationBlock:OrganizationBlock": "OrganizationBlock"
  }
 },
 {
  "pkg": "github",
  "mod": "index/organizationProject",
  "fqn": "pulumi_github",
  "classes": {
   "github:index/organizationProject:OrganizationProject": "OrganizationProject"
  }
 },
 {
  "pkg": "github",
  "mod": "index/organizationWebhook",
  "fqn": "pulumi_github",
  "classes": {
   "github:index/organizationWebhook:OrganizationWebhook": "OrganizationWebhook"
  }
 },
 {
  "pkg": "github",
  "mod": "index/projectCard",
  "fqn": "pulumi_github",
  "classes": {
   "github:index/projectCard:ProjectCard": "ProjectCard"
  }
 },
 {
  "pkg": "github",
  "mod": "index/projectColumn",
  "fqn": "pulumi_github",
  "classes": {
   "github:index/projectColumn:ProjectColumn": "ProjectColumn"
  }
 },
 {
  "pkg": "github",
  "mod": "index/repository",
  "fqn": "pulumi_github",
  "classes": {
   "github:index/repository:Repository": "Repository"
  }
 },
 {
  "pkg": "github",
  "mod": "index/repositoryCollaborator",
  "fqn": "pulumi_github",
  "classes": {
   "github:index/repositoryCollaborator:RepositoryCollaborator": "RepositoryCollaborator"
  }
 },
 {
  "pkg": "github",
  "mod": "index/repositoryDeployKey",
  "fqn": "pulumi_github",
  "classes": {
   "github:index/repositoryDeployKey:RepositoryDeployKey": "RepositoryDeployKey"
  }
 },
 {
  "pkg": "github",
  "mod": "index/repositoryEnvironment",
  "fqn": "pulumi_github",
  "classes": {
   "github:index/repositoryEnvironment:RepositoryEnvironment": "RepositoryEnvironment"
  }
 },
 {
  "pkg": "github",
  "mod": "index/repositoryFile",
  "fqn": "pulumi_github",
  "classes": {
   "github:index/repositoryFile:RepositoryFile": "RepositoryFile"
  }
 },
 {
  "pkg": "github",
  "mod": "index/repositoryMilestone",
  "fqn": "pulumi_github",
  "classes": {
   "github:index/repositoryMilestone:RepositoryMilestone": "RepositoryMilestone"
  }
 },
 {
  "pkg": "github",
  "mod": "index/repositoryProject",
  "fqn": "pulumi_github",
  "classes": {
   "github:index/repositoryProject:RepositoryProject": "RepositoryProject"
  }
 },
 {
  "pkg": "github",
  "mod": "index/repositoryPullRequest",
  "fqn": "pulumi_github",
  "classes": {
   "github:index/repositoryPullRequest:RepositoryPullRequest": "RepositoryPullRequest"
  }
 },
 {
  "pkg": "github",
  "mod": "index/repositoryWebhook",
  "fqn": "pulumi_github",
  "classes": {
   "github:index/repositoryWebhook:RepositoryWebhook": "RepositoryWebhook"
  }
 },
 {
  "pkg": "github",
  "mod": "index/team",
  "fqn": "pulumi_github",
  "classes": {
   "github:index/team:Team": "Team"
  }
 },
 {
  "pkg": "github",
  "mod": "index/teamMembership",
  "fqn": "pulumi_github",
  "classes": {
   "github:index/teamMembership:TeamMembership": "TeamMembership"
  }
 },
 {
  "pkg": "github",
  "mod": "index/teamRepository",
  "fqn": "pulumi_github",
  "classes": {
   "github:index/teamRepository:TeamRepository": "TeamRepository"
  }
 },
 {
  "pkg": "github",
  "mod": "index/teamSyncGroupMapping",
  "fqn": "pulumi_github",
  "classes": {
   "github:index/teamSyncGroupMapping:TeamSyncGroupMapping": "TeamSyncGroupMapping"
  }
 },
 {
  "pkg": "github",
  "mod": "index/userGpgKey",
  "fqn": "pulumi_github",
  "classes": {
   "github:index/userGpgKey:UserGpgKey": "UserGpgKey"
  }
 },
 {
  "pkg": "github",
  "mod": "index/userInvitationAccepter",
  "fqn": "pulumi_github",
  "classes": {
   "github:index/userInvitationAccepter:UserInvitationAccepter": "UserInvitationAccepter"
  }
 },
 {
  "pkg": "github",
  "mod": "index/userSshKey",
  "fqn": "pulumi_github",
  "classes": {
   "github:index/userSshKey:UserSshKey": "UserSshKey"
  }
 }
]
""",
    resource_packages="""
[
 {
  "pkg": "github",
  "token": "pulumi:providers:github",
  "fqn": "pulumi_github",
  "class": "Provider"
 }
]
"""
)



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities

__all__ = [
    'GetBranchResult',
    'AwaitableGetBranchResult',
    'get_branch',
]

@pulumi.output_type
class GetBranchResult:
    """
    A collection of values returned by getBranch.
    """
    def __init__(__self__, branch=None, etag=None, id=None, ref=None, repository=None, sha=None):
        if branch and not isinstance(branch, str):
            raise TypeError("Expected argument 'branch' to be a str")
        pulumi.set(__self__, "branch", branch)
        if etag and not isinstance(etag, str):
            raise TypeError("Expected argument 'etag' to be a str")
        pulumi.set(__self__, "etag", etag)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if ref and not isinstance(ref, str):
            raise TypeError("Expected argument 'ref' to be a str")
        pulumi.set(__self__, "ref", ref)
        if repository and not isinstance(repository, str):
            raise TypeError("Expected argument 'repository' to be a str")
        pulumi.set(__self__, "repository", repository)
        if sha and not isinstance(sha, str):
            raise TypeError("Expected argument 'sha' to be a str")
        pulumi.set(__self__, "sha", sha)

    @property
    @pulumi.getter
    def branch(self) -> str:
        return pulumi.get(self, "branch")

    @property
    @pulumi.getter
    def etag(self) -> str:
        """
        An etag representing the Branch object.
        """
        return pulumi.get(self, "etag")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def ref(self) -> str:
        """
        A string representing a branch reference, in the form of `refs/heads/<branch>`.
        """
        return pulumi.get(self, "ref")

    @property
    @pulumi.getter
    def repository(self) -> str:
        return pulumi.get(self, "repository")

    @property
    @pulumi.getter
    def sha(self) -> str:
        """
        A string storing the reference's `HEAD` commit's SHA1.
        """
        return pulumi.get(self, "sha")


class AwaitableGetBranchResult(GetBranchResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetBranchResult(
            branch=self.branch,
            etag=self.etag,
            id=self.id,
            ref=self.ref,
            repository=self.repository,
            sha=self.sha)


def get_branch(branch: Optional[str] = None,
               repository: Optional[str] = None,
               opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetBranchResult:
    """
    Use this data source to retrieve information about a repository branch.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_github as github

    development = github.get_branch(branch="development",
        repository="example")
    ```


    :param str branch: The repository branch to create.
    :param str repository: The GitHub repository name.
    """
    __args__ = dict()
    __args__['branch'] = branch
    __args__['repository'] = repository
    if opts is None:
        opts = pulumi.InvokeOptions()
    if opts.version is None:
        opts.version = _utilities.get_version()
    __ret__ = pulumi.runtime.invoke('github:index/getBranch:getBranch', __args__, opts=opts, typ=GetBranchResult).value

    return AwaitableGetBranchResult(
        branch=__ret__.branch,
        etag=__ret__.etag,
        id=__ret__.id,
        ref=__ret__.ref,
        repository=__ret__.repository,
        sha=__ret__.sha)
